@@ -2,8 +2,6 @@
 Scene release search and check
 """
 
-import asyncio
-
 from .. import errors
 from ..utils import fs, scene, types
 from . import JobBase
@@ -46,31 +44,28 @@ class SceneSearchJob(JobBase):
 
     def execute(self):
         """Send search query"""
+        self.add_task(self._search(), finish_when_done=True)
+
+    async def _search(self):
         try:
             query = scene.SceneQuery.from_string(self._content_path)
         except errors.SceneError as e:
             self.error(e)
         else:
-            self._search_task = asyncio.ensure_future(
-                scene.search(query=query),
-            )
-            self._search_task.add_done_callback(self._handle_results)
-
-    def _handle_results(self, task):
-        try:
-            results = task.result()
-        except (errors.RequestError, errors.SceneError) as e:
-            self.error(e)
-        else:
-            _log.debug('Handling results: %r', results)
-            if results:
-                for result in results:
-                    self.send(result)
+            try:
+                results = await scene.search(query)
+            except (errors.RequestError, errors.SceneError) as e:
+                self.error(e)
             else:
-                self.error('No results')
-            self.signal.emit('search_results', results)
-        finally:
-            self.finish()
+                _log.debug('Handling results: %r', results)
+                if results:
+                    for result in results:
+                        self.send(result)
+                else:
+                    self.error('No results')
+                self.signal.emit('search_results', results)
+            finally:
+                self.finish()
 
 
 class SceneCheckJob(JobBase):
@@ -137,12 +132,10 @@ class SceneCheckJob(JobBase):
             self.signal.emit('ask_is_scene_release', types.SceneCheckResult.unknown)
         except errors.SceneError as e:
             self.error(e)
-        except BaseException as e:
-            self.exception(e)
 
     def execute(self):
         """Start asynchronous background worker task"""
-        asyncio.ensure_future(
+        self.add_task(
             self._catch_errors(
                 self._find_release_name()
             )
@@ -189,7 +182,7 @@ class SceneCheckJob(JobBase):
         """
         _log.debug('User selected release name: %r', release_name)
         if release_name:
-            asyncio.ensure_future(
+            self.add_task(
                 self._catch_errors(
                     self._verify_release(release_name)
                 )
