@@ -17,39 +17,6 @@ class BhdTracker(TrackerBase):
     name = 'bhd'
     label = 'BHD'
 
-    argument_definitions = {
-        ('--draft', '-d'): {
-            'help': 'Upload as draft',
-            'action': 'store_true',
-            # The default value must be None so
-            # uis.tui.commands.submit.tracker_options doesn't always overwrite
-            # the value with the config file value.
-            'default': None,
-        },
-        ('--personal-rip', '-p'): {
-            'help': 'Tag as your own encode',
-            'action': 'store_true',
-        },
-        ('--custom-edition', '-e'): {
-            'help': 'Non-standard edition, e.g. "Final Cut"',
-            'default': '',
-        },
-        ('--special', '-s'): {
-            'help': 'Tag as special episode, e.g. Christmas special (ignored for movie uploads)',
-            'action': 'store_true',
-        },
-        ('--description', '--desc'): {
-            'help': 'Only generate description (do not upload anything)',
-            'action': 'store_true',
-        },
-        ('--screenshots', '--ss'): {
-            'help': ('How many screenshots to make '
-                     f'(min={BhdTrackerConfig.defaults["screenshots"].min}, '
-                     f'max={BhdTrackerConfig.defaults["screenshots"].max})'),
-            'type': utils.argtypes.number_of_screenshots(BhdTrackerConfig),
-        },
-    }
-
     TrackerConfig = BhdTrackerConfig
     TrackerJobs = BhdTrackerJobs
 
