@@ -33,6 +33,14 @@ _guessit = LazyModule(module='guessit.api', name='_guessit', namespace=globals()
 
 
 class _translated_property:
+    """
+    Property that is automatically translated on lookup
+
+    The translation is based on a mapping on the parent instance. It must be
+    available as ``_translate``. It maps regular expressions to replacement
+    strings. All regular expressions are applied in order.
+    """
+
     def __init__(self, fget=None, fset=None, fdel=None, doc=None):
         self.name = fget.__name__
         self.fget = fget
@@ -126,7 +134,10 @@ class ReleaseName(collections.abc.Mapping):
         self._name = name
         self._info = ReleaseInfo(str(name) if name is not None else self._path)
         self._translate = translate or {}
-        self._imdb = webdbs.imdb.ImdbApi()
+
+    @cached_property
+    def _imdb(self):
+        return webdbs.imdb.ImdbApi()
 
     def set_release_info(self, path):
         """
@@ -589,11 +600,11 @@ class ReleaseName(collections.abc.Mapping):
                 return False
         return True
 
-    async def fetch_info(self, id, callback=None):
+    async def fetch_info(self, *, imdb_id=None, callback=None):
         """
         Fill in information from IMDb
 
-        :param str id: IMDb ID
+        :param str imdb_id: IMDb ID
         :param callable callback: Function to call after fetching; gets the
             instance (`self`) as a keyword argument
 
@@ -607,17 +618,23 @@ class ReleaseName(collections.abc.Mapping):
 
         :return: The method's instance (`self`) for convenience
         """
-        await self._update_attributes(id)
+        # Theoretically, we should use also use `tmdb_id` and `tvmaze_id` to
+        # lookup attributes. Unfortunately, IMDb is the only usable source for
+        # the information we need.
+        for db_name, id in (('_imdb', imdb_id),):
+            db = getattr(self, db_name)
+            await self._update_attributes(db, id)
+        await self._update_type(self._imdb, id)
         await self._update_year_required()
         _log.debug('Release name updated with IMDb info: %s', self)
+
         if callback is not None:
             callback(self)
         return self
 
-    async def _update_attributes(self, id):
-        info = await self._imdb.gather(
+    async def _update_attributes(self, db, id):
+        info = await db.gather(
             id,
-            'type',
             'title_english',
             'title_original',
             'year',
@@ -631,11 +648,13 @@ class ReleaseName(collections.abc.Mapping):
             if info[key]:
                 setattr(self, attr, info[key])
 
-        # Use type from IMDb if known. ReleaseInfo can misdetect type (e.g. if
-        # mini-series doesn't contain "S01"). But if ReleaseInfo detected an
-        # episode (e.g. "S04E03"), it's unlikely to be wrong.
-        if info['type'] and self.type is not ReleaseType.episode:
-            self.type = info['type']
+    async def _update_type(self, db, id):
+        # Use type from database if possible. ReleaseInfo can misdetect type
+        # (e.g. if mini-series doesn't contain "S01"). But if ReleaseInfo
+        # detected an episode (e.g. "S04E03"), it's unlikely to be wrong.
+        db_type = await db.type(id)
+        if db_type and self.type is not ReleaseType.episode:
+            self.type = db_type
 
     async def _update_year_required(self):
         if self.type in (ReleaseType.season, ReleaseType.episode):
@@ -647,7 +666,7 @@ class ReleaseName(collections.abc.Mapping):
                 return unidecode.unidecode(title.casefold())
 
             title_normalized = normalize_title(self.title)
-            same_titles = tuple(f'{r.title} year={r.year} id={r.id}' for r in results
+            same_titles = tuple(f'{r.title} year={r.year} imdb_id={r.id}' for r in results
                                 if normalize_title(r.title) == title_normalized)
             if len(same_titles) >= 2:
                 _log.debug('Found multiple search results for %r: %r', query, same_titles)
@@ -923,6 +942,7 @@ class ReleaseInfo(collections.abc.MutableMapping):
         'HDR10': re.compile(r'(?:[ \.]|^)(?i:HDR10)(?:[^\+]|$)'),
         'HDR': re.compile(r'(?:[ \.]|^)(?i:HDR)(?:[^10\+]|$)'),
     }
+    _remastered_regex = re.compile(r'(?:[ \.]|^)((?i:4k[ \.]+|)(?i:remaster(?:ed|)|restored))(?:[ \.]|$)')
 
     def _get_edition(self):
         edition = _as_list(self._guess.get('edition'))
@@ -944,6 +964,20 @@ class ReleaseInfo(collections.abc.MutableMapping):
             edition.append('OAR')
         if 'Dual Audio' in guessit_other:
             edition.append('Dual Audio')
+        if '2in1' in guessit_other:
+            edition.append('2in1')
+
+        def is_4k_source():
+            # guessit only detects remastered, not if it's from 4k
+            match = self._remastered_regex.search(self.release_name_params)
+            if match:
+                remastered_string = match.group(1)
+                return '4k' in remastered_string.lower()
+
+        if 'Remastered' in edition and is_4k_source():
+            edition[edition.index('Remastered')] = '4k Remastered'
+        elif 'Restored' in edition and is_4k_source():
+            edition[edition.index('Restored')] = '4k Restored'
 
         # HDR format
         for hdr_format, regex in self._hdr_regexes.items():
@@ -958,9 +992,10 @@ class ReleaseInfo(collections.abc.MutableMapping):
 
     _streaming_service_regex = re.compile(r'[ \.]([A-Z]+)[ \.](?i:WEB-?(?:DL|Rip))(?:[ \.]|$)')
     _streaming_service_translation = {
-        re.compile(r'(?i:IT)') : 'iT',
+        re.compile(r'(?i:IT)'): 'iT',
+        re.compile(r'(?i:ATVP)'): 'APTV',
         # Not a streaming service
-        re.compile(r'OAR') : '',  # Original Aspect Ratio
+        re.compile(r'OAR'): '',  # Original Aspect Ratio
     }
 
     def _get_service(self):
@@ -1236,7 +1271,7 @@ class Episodes(dict):
         return super().__init__(validated_args)
 
     def remove_specific_episodes(self):
-        """Remove episodes from each season, leaving only complete season"""
+        """Remove episodes from each season, leaving only complete seasons"""
         for season in tuple(self):
             if season:
                 self[season] = ()
