@@ -2,6 +2,7 @@
 String formatting and parsing
 """
 
+import importlib
 import re
 import sys
 
@@ -9,6 +10,23 @@ import logging  # isort:skip
 _log = logging.getLogger(__name__)
 
 
+def group(name):
+    """
+    Return character group, e.g. "digits"
+
+    This function simply returns an attribute from the built-in :mod:`string`
+    module.
+
+    :raise ValueError: if the built-in :mod:`string` module doesn't have
+        attribute `name`
+    """
+    string_module = importlib.import_module('string')
+    try:
+        return getattr(string_module, name)
+    except AttributeError:
+        raise ValueError(f'No such character group: {name!r}')
+
+
 def autodecode(bytes):
     """
     Decode `bytes` with autodetected encoding
@@ -44,7 +62,13 @@ def capitalize(text):
 
 
 def star_rating(rating, max_rating=10):
-    '''Return star rating string with the characters "★", "⯪" and "☆"'''
+    """
+    Return star rating string with the characters "★" (U+2605), "⯪" (U+2BEA) and
+    "☆" (U+2605)
+
+    :param float,int rating: Number between 0 and `max_rating`
+    :param float,int max_rating: Maximum rating
+    """
     import math
     rating = min(max_rating, max(0, rating))
     left = '\u2605' * math.floor(rating)
